@@ -268,3 +268,20 @@ class StackLocs(Stack):
                 logger1.debug(f'lock.release() ID: {id}')
         except StackElementNotExist:
             pass
+
+
+def get_list_nums_key_dict(data):
+    res = []
+    if isinstance(data, dict):
+        if data.get('0'):
+            idx = 0
+            while True:
+                _data = data.get(str(idx))
+                if isinstance(_data, dict):
+                    res.append(_data)
+                else:
+                    break
+                idx += 1
+        else:
+            res.append(data)
+    return res
