@@ -16,6 +16,7 @@ from isc_common.datetime import DateToStr
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.ws.webSocket import WebSocket
+from kaf_pas.planing.models.status_operation_types import Status_operation_types
 from tracker.models.messages_state import Messages_state
 from tracker.models.messages_theme import Messages_theme
 from twits.models.chat_user_user import Chat_user_user
@@ -27,6 +28,9 @@ logger = logging.getLogger(__name__)
 
 class LoginRequest(DSRequest):
     def __init__(self, request):
+        from reports.models.jasper_reports_users import Jasper_reports_users
+        from django.forms import model_to_dict
+
         DSRequest.__init__(self, request)
         data = self.get_data()
         login = data.get('login', None)
@@ -56,8 +60,17 @@ class LoginRequest(DSRequest):
                             self.response = dict(status=RPCResponseConstant.statusLoginIncorrect, errorMessage=f'Вход с логином "{login}" уже выполнен на {ip_address}')
                     else:
 
-                        from reports.models.jasper_reports_users import Jasper_reports_users
-                        from django.forms import model_to_dict
+                        operations_statuses = []
+                        for status_operation_types in Status_operation_types.objects.all():
+                            operations_statuses.append(
+                                dict(
+                                    opertype_id=status_operation_types.opertype.id,
+                                    opertype__code=status_operation_types.opertype.code,
+                                    status_id=status_operation_types.id,
+                                    status__code=status_operation_types.code,
+                                    status__name=status_operation_types.name,
+                                ))
+
                         self.response = dict(
                             captionUser=user.get_short_name,
                             chatInfo=LoginRequest.get_chats(user),
@@ -88,6 +101,7 @@ class LoginRequest(DSRequest):
                             ws_channel=ws_channel,
                             ws_host=settings.WS_HOST,
                             ws_port=settings.WS_PORT,
+                            operations_statuses=operations_statuses,
                             jasper_reports=[dict(
                                 report=model_to_dict(item.report),
                                 editor_identifier=item.editor_identifier,
