@@ -1,6 +1,7 @@
 import logging
 
-from isc_common import ws
+from django.conf import settings
+
 from isc_common.models.base_ref import BaseRef, BaseRefManager, BaseRefQuerySet
 from isc_common.ws.webSocket import WebSocket
 
@@ -23,8 +24,8 @@ class ChatsManager(BaseRefManager):
             chatInfo=LoginRequest.get_chats(user)
         )
         WebSocket.send_message(
-            host=ws.WS_HOST,
-            port=ws.WS_PORT,
+            host=settings.WS_HOST,
+            port=settings.WS_PORT,
             channel=f'common_{user.username}',
             message=message,
             logger=logger
